<?php
use \App\Enums\TransactionStatus as TStatus;
use \App\Enums\TransactionType as TType;
use \App\Enums\TransactionCalcType as TCType;

$base_currency = base_currency();
$applyBonus = true;

if (module_exist('MultiReferral', 'addon') && data_get($transaction, 'meta.referral.action') == 'investment') {
    $multiReferral = app()->get('multireferral');
    $applyBonus = $multiReferral->validateInvestmentBonus($transaction);
}
?>
<div class="nk-tb-col">
    <div class="nk-tnx-type">
        <div class="nk-tnx-type-badge">
            <?php echo tnx_type_icon($transaction, 'tnx-type-icon'); ?>

        </div>
        <div class="nk-tnx-type-text">
            <span class="tb-lead">
                <?php if($transaction->type == TType::TRANSFER): ?>
                    <?php echo e(($transaction->calc == TCType::DEBIT) ? __("Send Funds") : __("Receive Funds")); ?>

                <?php else: ?>
                    <?php echo e($transaction->type_of_fund); ?>

                <?php endif; ?>
            </span>
            <span class="nk-tnx-meta">
                <span class="date"><?php echo e(show_date($transaction->created_at)); ?></span>
                <span class="status dot-join<?php echo e(($transaction->status==TStatus::CANCELLED) ? ' text-danger' : ''); ?>">
                    <?php echo e(($transaction->type == TType::INVESTMENT && in_array($transaction->status, [TStatus::PENDING])) ? __("Locked") : __(ucfirst($transaction->status))); ?>

                </span>
            </span>
        </div>
    </div>
</div>
<div class="nk-tb-col tb-col-sm">
    <span class="tb-lead-sub">
        <?php echo e(the_uid($transaction->customer->id)); ?>

        <em class="icon ni ni-info text-soft fs-13px" data-toggle="tooltip" title="<?php echo e($transaction->customer->name); ?> (<?php echo e(str_protect($transaction->customer->email)); ?>)"></em>
    </span>
    <span class="tb-sub"><?php echo e(__('via :Method', ['method' => $transaction->method_name])); ?></span>
</div>
<div class="nk-tb-col tb-col-lg">
    <span class="tb-lead-sub"><?php echo e(data_get($transaction, 'tnx')); ?></span>
    <span class="badge badge-dot <?php echo e(data_get($transaction, 'type') == TType::DEPOSIT ? 'badge-success' : 'badge-warning'); ?>">
        <?php echo e(ucfirst(__(data_get($transaction, 'type')))); ?>

    </span>
</div>
<div class="nk-tb-col text-right">
    <?php if($transaction->calc == TCType::CREDIT): ?>
        <span class="tb-amount">+ <?php echo e(amount_z(data_get($transaction, 'tnx_amount'), data_get($transaction, 'tnx_currency'), ['dp' => 'calc'])); ?> <span><?php echo e(data_get($transaction, 'tnx_currency')); ?></span></span>
        <span class="tb-amount-sm"><?php echo e(amount_z(data_get($transaction, 'amount'), $base_currency, ['dp' => 'calc'])); ?> <?php echo e($base_currency); ?></span>
    <?php else: ?>
        <span class="tb-amount">- <?php echo e(amount_z(data_get($transaction, 'tnx_total'), data_get($transaction, 'tnx_currency'), ['dp' => 'calc'])); ?>

            <span><?php echo e(data_get($transaction, 'tnx_currency')); ?></span>
        </span>
        <span class="tb-amount-sm"><?php echo e(amount_z(data_get($transaction, 'total'), $base_currency, ['dp' => 'calc'])); ?> <?php echo e($base_currency); ?></span>
    <?php endif; ?>
</div>
<div class="nk-tb-col nk-tb-col-tools">
    <ul class="nk-tb-actions gx-2">

        <?php if(in_array($transaction->status, [TStatus::PENDING, TStatus::ONHOLD, TStatus::CONFIRMED]) && $transaction->type != TType::INVESTMENT): ?>
        <li class="nk-tb-action-hidden">
            <a href="javascript:void(0)" class="btn btn-sm btn-trigger btn-icon atx-upd btn-tooltip"
                data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>" data-action="reject"
                data-state="<?php echo e(TStatus::CANCELLED); ?>" title="<?php echo e(__('Reject')); ?>"><em class="icon ni ni-cross-fill-c"></em></a>
        </li>
        <?php endif; ?>

        <?php if( ($transaction->type == TType::DEPOSIT || $transaction->type == TType::TRANSFER) && in_array($transaction->status, [TStatus::PENDING, TStatus::ONHOLD]) && $transaction->is_online == false): ?>
        <li class="nk-tb-action-hidden">
            <a href="javascript:void(0)" class="btn btn-sm btn-icon btn-trigger atx-upd btn-tooltip"
                data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                data-action="approve"
                data-state="<?php echo e(TStatus::COMPLETED); ?>" title="<?php echo e(__('Approve')); ?>"><em class="icon ni ni-check-fill-c"></em></a>
        </li>
        <?php endif; ?>

        <?php if( $transaction->type == TType::WITHDRAW && in_array($transaction->status, [TStatus::PENDING, TStatus::CONFIRMED]) ): ?>
        <li class="nk-tb-action-hidden">
            <a href="javascript:void(0)" class="btn btn-sm btn-icon btn-trigger atx-upd btn-tooltip"
                data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                data-action="<?php echo e((($transaction->status == TStatus::CONFIRMED) ? 'approve' : 'confirm')); ?>"
                data-state="<?php echo e((($transaction->status == TStatus::CONFIRMED) ? TStatus::COMPLETED : TStatus::CONFIRMED)); ?>"
                title="<?php echo e((($transaction->status == TStatus::CONFIRMED) ? __('Complete') : __('Confirm'))); ?>"><em class="icon ni ni-check-fill-c"></em></a>
        </li>
        <?php endif; ?>

        <?php if( $transaction->type == TType::REFERRAL && in_array($transaction->status, [TStatus::PENDING]) && $applyBonus): ?>
        <li class="nk-tb-action-hidden">
            <a href="javascript:void(0)" class="btn btn-sm btn-icon btn-trigger atx-upd btn-tooltip"
                data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                data-action="approve"
                data-state="<?php echo e(TStatus::COMPLETED); ?>" title="<?php echo e(__('Approve')); ?>"><em class="icon ni ni-check-fill-c"></em></a>
        </li>
        <?php endif; ?>

        <li class="nk-tb-action-hidden">
            <a href="javascript:void(0)" class="btn btn-sm btn-trigger btn-icon uaj-tnx btn-tooltip" data-action="view" data-view="tnx"
            data-uid="<?php echo e(the_hash($transaction->id)); ?>" title="<?php echo e(__('Details')); ?>"><em class="icon ni ni-eye-fill"></em></a>
        </li>

        <li>
            <div class="dropdown">
                <a href="#" class="dropdown-toggle btn btn-sm btn-icon btn-trigger" data-toggle="dropdown"><em class="icon ni ni-more-h"></em></a>
                <div class="dropdown-menu dropdown-menu-right">
                    <ul class="link-list-opt no-bdr">
                        <li><a href="javascript:void(0)" class="uaj-tnx" data-action="view" data-view="tnx" data-uid="<?php echo e(the_hash($transaction->id)); ?>"><em class="icon ni ni-eye"></em><span><?php echo e(__('View Details')); ?></span></a></li>
                        <li><a href="javascript:void(0)" class="uaj-tnx" data-action="view" data-view="profile" data-uid="<?php echo e(the_hash($transaction->id)); ?>"><em class="icon ni ni-user-alt"></em><span><?php echo e(__('User Profile')); ?></span></a></li>

                        <?php if( in_array($transaction->status, [TStatus::PENDING, TStatus::ONHOLD, TStatus::CONFIRMED]) ): ?>

                        <?php if($transaction->type != TType::INVESTMENT): ?>
                        <li class="divider"></li>
                        <?php endif; ?>

                        <?php if( $transaction->type == TType::WITHDRAW && in_array($transaction->status, [TStatus::PENDING, TStatus::CONFIRMED]) ): ?>
                        <li><a class="atx-upd" href="javascript:void(0)" data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                            data-action="<?php echo e((($transaction->status == TStatus::CONFIRMED) ? 'approve' : 'confirm')); ?>"
                            data-state="<?php echo e((($transaction->status == TStatus::CONFIRMED) ? TStatus::COMPLETED : TStatus::CONFIRMED)); ?>">
                            <em class="icon ni ni-check-circle-cut"></em><span><?php echo e((($transaction->status == TStatus::CONFIRMED) ? __('Complete') : __('Confirm'))); ?></span></a>
                        </li>
                        <?php endif; ?>

                        <?php if( $transaction->type == TType::DEPOSIT && in_array($transaction->status, [TStatus::PENDING, TStatus::ONHOLD]) ): ?>
                        <li><a class="atx-upd" href="javascript:void(0)" data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                            data-action="<?php echo e((($transaction->is_online) ? 'online' : 'approve')); ?>"
                            data-state="<?php echo e((($transaction->is_online) ? 'check' : TStatus::COMPLETED)); ?>">
                            <?php if($transaction->is_online): ?>
                            <em class="icon ni ni-reload"></em><span><?php echo e(__('Check Status')); ?></span></a>
                            <?php else: ?>
                            <em class="icon ni ni-check-c"></em><span><?php echo e(__('Approve')); ?></span></a>
                            <?php endif; ?>
                        </li>
                        <?php endif; ?>

                        <?php if( $transaction->type == TType::REFERRAL && in_array($transaction->status, [TStatus::PENDING]) && $applyBonus): ?>
                        <li><a class="atx-upd" href="javascript:void(0)" data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>"
                            data-action="approve"
                            data-state="<?php echo e(TStatus::COMPLETED); ?>">
                            <em class="icon ni ni-check-c"></em><span><?php echo e(__('Approve')); ?></span></a>
                        </li>
                        <?php endif; ?>

                        <?php if( $transaction->type != TType::INVESTMENT ): ?>
                        <li><a class="atx-upd" href="javascript:void(0)" data-uid="<?php echo e(the_hash($transaction->id)); ?>" data-tnx="<?php echo e($transaction->tnx); ?>" data-action="reject" data-state="<?php echo e(TStatus::CANCELLED); ?>">
                            <em class="icon ni ni-cross-c"></em><span><?php echo e(__('Reject')); ?></span></a>
                        </li>
                        <?php endif; ?>

                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </li>
    </ul>
</div>
<?php /**PATH /home/unitedfi/trustexchangetrade.com/core_invapp/resources/views/admin/transaction/trans-row.blade.php ENDPATH**/ ?>